emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/emacs-lisp/bytecomp.el,v


From: Miles Bader
Subject: [Emacs-diffs] Changes to emacs/lisp/emacs-lisp/bytecomp.el,v
Date: Fri, 01 Feb 2008 16:03:24 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Miles Bader <miles>     08/02/01 16:01:31

Index: lisp/emacs-lisp/bytecomp.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/emacs-lisp/bytecomp.el,v
retrieving revision 2.228
retrieving revision 2.229
diff -u -b -r2.228 -r2.229
--- lisp/emacs-lisp/bytecomp.el 8 Jan 2008 20:45:36 -0000       2.228
+++ lisp/emacs-lisp/bytecomp.el 1 Feb 2008 16:01:26 -0000       2.229
@@ -864,7 +864,7 @@
               (setcar (cdr bytes) (logand pc 255))
               (setcar bytes (lsh pc -8))))
        (setq patchlist (cdr patchlist))))
-    (concat (nreverse bytes))))
+    (string-make-unibyte (concat (nreverse bytes)))))
 
 
 ;;; compile-time evaluation
@@ -1949,13 +1949,13 @@
        (delete-region (point) (progn (re-search-forward "^(")
                                      (beginning-of-line)
                                      (point)))
-       (insert ";;; This file contains multibyte non-ASCII characters\n"
-               ";;; and therefore cannot be loaded into Emacs 19.\n")
-       ;; Replace "19" or "19.29" with "20", twice.
+       (insert ";;; This file contains utf-8 non-ASCII characters\n"
+               ";;; and therefore cannot be loaded into Emacs 21 or 
earlier.\n")
+       ;; Replace "19" or "19.29" with "22", twice.
        (re-search-forward "19\\(\\.[0-9]+\\)")
-       (replace-match "20")
+       (replace-match "23")
        (re-search-forward "19\\(\\.[0-9]+\\)")
-       (replace-match "20")
+       (replace-match "23")
        ;; Now compensate for the change in size,
        ;; to make sure all positions in the file remain valid.
        (setq delta (- (point-max) old-header-end))
@@ -1970,7 +1970,7 @@
       (set-buffer outbuffer)
       (goto-char (point-min))
       ;; The magic number of .elc files is ";ELC", or 0x3B454C43.  After
       ;; that is the file-format version number (18, 19 or 20) as a
       ;; byte, followed by some nulls.  The primary motivation for doing
       ;; this is to get some binary characters up in the first line of
       ;; the file so that `diff' will simply say "Binary files differ"
@@ -1982,7 +1982,7 @@
 
       (insert
        ";ELC"
-       (if (byte-compile-version-cond byte-compile-compatibility) 18 20)
+       (if (byte-compile-version-cond byte-compile-compatibility) 18 23)
        "\000\000\000\n"
        )
       (insert ";;; Compiled by "
@@ -2038,7 +2038,7 @@
             ;; Insert semicolons as ballast, so that byte-compile-fix-header
             ;; can delete them so as to keep the buffer positions
             ;; constant for the actual compiled code.
-            
";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n\n"))
+          
";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n\n"))
        ;; Here if we want Emacs 18 compatibility.
        (when dynamic-docstrings
          (error "Version-18 compatibility doesn't support dynamic doc 
strings"))
@@ -3485,6 +3485,8 @@
 (byte-defop-compiler-1 mapc byte-compile-funarg)
 (byte-defop-compiler-1 maphash byte-compile-funarg)
 (byte-defop-compiler-1 map-char-table byte-compile-funarg)
+(byte-defop-compiler-1 map-char-table byte-compile-funarg-2)
+;; map-charset-chars should be funarg but has optional third arg
 (byte-defop-compiler-1 sort byte-compile-funarg-2)
 (byte-defop-compiler-1 let)
 (byte-defop-compiler-1 let*)
@@ -1970,7 +1970,7 @@
       (goto-char (point-min))
       ;; The magic number of .elc files is ";ELC", or 0x3B454C43.  After
-      ;; that is the file-format version number (18, 19 or 20) as a
+      ;; that is the file-format version number (18, 19, 20, or 23) as a
       ;; byte, followed by some nulls.  The primary motivation for doing
       ;; this is to get some binary characters up in the first line of




reply via email to

[Prev in Thread] Current Thread [Next in Thread]